=====================
ProbabilityDict class
=====================

This class is similar to the `SamplesDict class <SamplesDict.html>`_ but instead
of storing a collection of posterior samples for each parameter, it stores the
analytic PDF for each parameter. The analytic PDF is stored as a
`DiscretePDF object <pdf.html>`_.

.. autoclass:: pesummary.utils.probability_dict.ProbabilityDict
